<?php

require '../connect.php';

$response = array();

$name = $_POST['name'] ?? '';
$quantity = isset($_POST['quantity']) ? intval($_POST['quantity']) : 0;
$unit_price = isset($_POST['unit_price']) ? floatval($_POST['unit_price']) : 0.0;
$total_price = isset($_POST['total_price']) ? floatval($_POST['total_price']) : 0.0;
$mode_of_payment = $_POST['mode_of_payment'] ?? '';
$user_id = $_POST['user_id'] ?? 0; 
$store_id = $_POST['store_id'] ?? '';

if (empty($name) || $quantity <= 0 || $unit_price <= 0 || $total_price <= 0 || empty($mode_of_payment) || $user_id <= 0 || empty($store_id)) {
    $response['success'] = false;
    $response['message'] = 'Error: Missing or invalid parameters';
    echo json_encode($response);
    exit;
}

$check_query = "SELECT quantity FROM stock WHERE name = ? AND store_id = ?";
$stmt = mysqli_prepare($con, $check_query);
if (!$stmt) {
    $response['success'] = false;
    $response['message'] = 'Failed to prepare statement: ' . mysqli_error($con);
    echo json_encode($response);
    exit;
}

mysqli_stmt_bind_param($stmt, "ss", $name, $store_id);
mysqli_stmt_execute($stmt);
mysqli_stmt_bind_result($stmt, $available_quantity);

if (mysqli_stmt_fetch($stmt)) {
    if ($available_quantity >= $quantity) {
        // Sufficient stock, proceed with sale
        mysqli_stmt_close($stmt);

        // Begin a transaction
        mysqli_begin_transaction($con);

        try {
            // Insert sales record
            $insert_query = "INSERT INTO sales (name, quantity, unit_price, total_price, mode_of_payment, user_id, store_id) VALUES (?, ?, ?, ?, ?, ?, ?)";
            $stmt = mysqli_prepare($con, $insert_query);
            if (!$stmt) {
                throw new Exception('Failed to prepare insert statement: ' . mysqli_error($con));
            }
            mysqli_stmt_bind_param($stmt, "siddsis", $name, $quantity, $unit_price, $total_price, $mode_of_payment, $user_id, $store_id);
            mysqli_stmt_execute($stmt);

            // Update stock
            $update_query = "UPDATE stock SET quantity = quantity - ? WHERE name = ? AND store_id = ?";
            $stmt = mysqli_prepare($con, $update_query);
            if (!$stmt) {
                throw new Exception('Failed to prepare update statement: ' . mysqli_error($con));
            }
            mysqli_stmt_bind_param($stmt, "iss", $quantity, $name, $store_id);
            mysqli_stmt_execute($stmt);

            // Commit transaction
            mysqli_commit($con);

            // Success response
            $response['success'] = true;
            $response['message'] = "Sales recorded successfully";

        } catch (Exception $e) {
            // Rollback transaction on error
            mysqli_rollback($con);

            // Error response
            $response['success'] = false;
            $response['message'] = "Error: " . $e->getMessage();
        }
    } else {
        // Insufficient stock
        $response['success'] = false;
        $response['message'] = "Insufficient stock for '$name'. Available: $available_quantity, Requested: $quantity";
    }
} else {
    // Product not found in stock
    $response['success'] = false;
    $response['message'] = "Product '$name' not found in stock";
}

// Close statement and database connection
mysqli_stmt_close($stmt);
mysqli_close($con);

// Print JSON response
echo json_encode($response);

?>






