<?php

require "../connect.php";

$flag['success'] = 0;
$flag['data'] = array();

// Check if store_id parameter is provided
if (!isset($_GET['store_id'])) {
    $flag['success'] = 0;
    $flag['message'] = 'Error: Missing store_id parameter';
    echo json_encode($flag);
    exit;
}

// Get the store_id from the URL parameter
$store_id = $_GET['store_id'];

// Select query to fetch stock data for a specific store
$select_query = "SELECT name, description, quantity, s_price FROM stock WHERE store_id = ?";

// Prepare the select query
$stmt = mysqli_prepare($con, $select_query);

if ($stmt) {
    // Bind the store_id parameter to the prepared statement
    mysqli_stmt_bind_param($stmt, "s", $store_id);
    
    // Execute the query
    mysqli_stmt_execute($stmt);
    
    // Bind result variables
    mysqli_stmt_bind_result($stmt, $name, $description, $quantity, $s_price);
    
    // Fetch results and store in response array
    while (mysqli_stmt_fetch($stmt)) {
        $stock_item = array(
            'name' => $name,
            'description' => $description,
            'quantity' => $quantity,
            's_price' => $s_price
        );
        $flag['data'][] = $stock_item;
    }
    
    // Set success flag
    $flag['success'] = 1;
    
    // Close statement
    mysqli_stmt_close($stmt);
} else {
    // If prepared statement creation failed, set error message
    $flag['message'] = "Error: " . mysqli_error($con);
}

// Send response
echo json_encode($flag);

// Close connection
mysqli_close($con);

?>

